@@ -48,6 +48,7 @@ class RepoEvents(Document):
     deletions = IntField(default=0)
     total = IntField(default=0)
     commit_files = ListField()
+    
     velocity_kpi = EmbeddedDocumentField(VelocityKPI)
 
     # Category and Tokens
@@ -75,119 +76,63 @@ class LinterScanEvent(EmbeddedDocument):
     linter_output = StringField()
 
 
-class MaturityKPI(EmbeddedDocument):
+class AutomationKPI(EmbeddedDocument):
     """The maturity KPI total and sub-totals."""
 
-    total = FloatField(default=0.0)
-    assets = FloatField(default=0.0)
-    tooling = FloatField(default=0.0)
-    automation = FloatField(default=0.0)
-    security = FloatField(default=0.0)
-
-    def __init__(self, load_dict=None, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        if load_dict:
-            self.total = load_dict["total"]
-            self.assets = load_dict["assets"]
-            self.tooling = load_dict["tooling"]
-            self.automation = load_dict["automation"]
-            self.security = load_dict["security"]
+    automation_total = FloatField(default=0.0)
+    iac = FloatField(default=0.0)
+    containers = FloatField(default=0.0)
+    build_tools = FloatField(default=0.0)
+    local_dev = FloatField(default=0.0)
 
 
-class QualityKPI(EmbeddedDocument):
+class CicdKPI(EmbeddedDocument):
     """The quality KPI total and sub-totals."""
 
-    total = FloatField(default=0.0)
+    cicd_total = FloatField(default=0.0)
     pipeline = FloatField(default=0.0)
     testing = FloatField(default=0.0)
     static_analyis = FloatField(default=0.0)
     deploy = FloatField(default=0.0)
 
-    def __init__(self, load_dict=None, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
 
-    def load(self, load_dict):
-        if load_dict:
-            self.total = load_dict["total"]
-            self.pipeline = load_dict["pipeline"]
-            self.testing = load_dict["testing"]
-            self.static_analysis = load_dict["static_analysis"]
-            self.deploy = load_dict["deploy"]
-
-
-class RiskKPI(EmbeddedDocument):
+class SecurityKPI(EmbeddedDocument):
     """The risk KPI total and sub-totals."""
 
-    total = FloatField(default=0.0)
+    secutiry_total = FloatField(default=0.0)
     secrets = FloatField(default=0.0)
     auth = FloatField(default=0.0)
     keys = FloatField(default=0.0)
     compliance = FloatField(default=0.0)
-    code_warnings = FloatField(default=0.0)
-    code_errors = FloatField(default=0.0)
-    devops_warnings = FloatField(default=0.0)
-    devops_errors = FloatField(default=0.0)
-
-    def __init__(self, load_dict=None, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        if load_dict:
-            self.total = load_dict["total"]
-            self.secrets = load_dict["secrets"]
-            self.auth = load_dict["auth"]
-            self.keys = load_dict["keys"]
-            self.compliance = load_dict["compliance"]
 
 
 class InfrastructureKPI(EmbeddedDocument):
     """The infrastructure KPI total and sub-totals."""
 
-    total = FloatField(default=0.0)
-    tags = FloatField(default=0.0)
+    infrastructure_total = FloatField(default=0.0)
     networking = FloatField(default=0.0)
     compute_resources = FloatField(default=0.0)
     environments = FloatField(default=0.0)
-
-    def __init__(self, load_dict=None, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        if load_dict:
-            self.total = load_dict["total"]
-            self.tags = load_dict["tags"]
-            self.networking = load_dict["networking"]
-            self.compute_resources = load_dict["compute_resources"]
-            self.environments = load_dict["environments"]
+    tags = FloatField(default=0.0)
 
 
-class InvestmentKPI(EmbeddedDocument):
+class IssuesTotal(EmbeddedDocument):
+    """The infrastructure KPI total and sub-totals."""
+    code_warnings = FloatField(default=0.0)
+    code_errors = FloatField(default=0.0)
+    devops_warnings = FloatField(default=0.0)
+    devops_errors = FloatField(default=0.0)
+
+
+class DevelopmentKPI(EmbeddedDocument):
     """The investment KPI total and sub-totals."""
 
-    total = FloatField(default=0.0)
+    development_total = FloatField(default=0.0)
     features = FloatField(default=0.0)
     defects = FloatField(default=0.0)
     devops = FloatField(default=0.0)
     debt = FloatField(default=0.0)
 
-    def __init__(self, load_dict=None, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        if load_dict:
-            self.total = load_dict["total"]
-            self.features = load_dict["features"]
-            self.defects = load_dict["defects"]
-            self.devops = load_dict["devops"]
-            self.debt = load_dict["debt"]
-
 
 class UserCommit(EmbeddedDocument):
     ''' User Commit '''
@@ -217,10 +162,10 @@ class CommitEvent(RepoEvents):
     linter_events = EmbeddedDocumentListField(LinterScanEvent)
 
     # Analysis fields
-    investment_kpi = EmbeddedDocumentField(InvestmentKPI)
-    maturity_kpi = EmbeddedDocumentField(MaturityKPI)
-    quality_kpi = EmbeddedDocumentField(QualityKPI)
-    risk_kpi = EmbeddedDocumentField(RiskKPI)
+    development_kpi = EmbeddedDocumentField(DevelopmentKPI)
+    automation_kpi = EmbeddedDocumentField(AutomationKPI)
+    cicd_kpi = EmbeddedDocumentField(CicdKPI)
+    security_kpi = EmbeddedDocumentField(SecurityKPI)
     infra_kpi = EmbeddedDocumentField(InfrastructureKPI)
 
 
