@@ -8,6 +8,7 @@ from celery import Celery
 from pymemcache.client.base import Client
 from aioinflux import InfluxDBClient
 import motor.motor_asyncio
+import redis
 
 
 class MongoSettings():
@@ -115,4 +116,18 @@ class MotorClient:
 
         db = client[db_name]
 
-        return db
\ No newline at end of file
+        return db
+
+
+class RedisClient:
+    client = None
+
+    def __new__(cls, host=None, port=None):
+        port = port if port else os.environ.get("REDIS_PORT", 6379)
+        host = (
+            host if host else os.environ.get("MEMCACHE_HOST", "host.docker.internal")
+        )
+
+        client = redis.Redis(host=host, port=port)
+
+        return client
